import httpm = require('./HttpClient');
import ifm = require("./interfaces/common/VsoBaseInterfaces");
import serm = require('./Serialization');
export interface IRestClientResponse {
    statusCode: number;
    result: any;
}
export declare class RestClient {
    client: httpm.HttpClient;
    versionParam: string;
    constructor(userAgent: string, handlers?: ifm.IRequestHandler[], socketTimeout?: number, versionParam?: string);
    get(requestUrl: string, apiVersion: string, additionalHeaders?: ifm.IHeaders): Promise<IRestClientResponse>;
    del(requestUrl: string, apiVersion: string, additionalHeaders?: ifm.IHeaders): Promise<IRestClientResponse>;
    create(requestUrl: string, apiVersion: string, resources: any, additionalHeaders?: ifm.IHeaders): Promise<IRestClientResponse>;
    update(requestUrl: string, apiVersion: string, resources: any, additionalHeaders?: ifm.IHeaders): Promise<IRestClientResponse>;
    replace(requestUrl: string, apiVersion: string, resources: any, additionalHeaders?: ifm.IHeaders): Promise<IRestClientResponse>;
    uploadStream(verb: string, requestUrl: string, apiVersion: string, stream: NodeJS.ReadableStream, additionalHeaders: ifm.IHeaders): Promise<IRestClientResponse>;
    createAcceptHeader(type: string, apiVersion?: string): string;
    private _processResponse(res);
}
export declare class RestCallbackClient {
    baseUrl: string;
    basePath: string;
    httpClient: httpm.HttpCallbackClient;
    versionParam: string;
    constructor(httpClient: httpm.HttpCallbackClient, versionParam?: string);
    get(url: string, apiVersion: string, customHeaders: ifm.IHeaders, onResult: (err: any, statusCode: number, obj: any) => void): void;
    del(url: string, apiVersion: string, customHeaders: ifm.IHeaders, onResult: (err: any, statusCode: number, obj: any) => void): void;
    create(url: string, apiVersion: string, resources: any, customHeaders: ifm.IHeaders, onResult: (err: any, statusCode: number, obj: any) => void, serializationData?: serm.SerializationData): void;
    update(url: string, apiVersion: string, resources: any, customHeaders: ifm.IHeaders, onResult: (err: any, statusCode: number, obj: any) => void, serializationData?: serm.SerializationData): void;
    options(url: string, onResult: (err: any, statusCode: number, obj: any) => void): void;
    uploadFile(verb: string, url: string, apiVersion: string, filePath: string, customHeaders: ifm.IHeaders, onResult: (err: any, statusCode: number, obj: any) => void, serializationData?: serm.SerializationData): void;
    uploadStream(verb: string, url: string, apiVersion: string, contentStream: NodeJS.ReadableStream, customHeaders: ifm.IHeaders, onResult: (err: any, statusCode: number, obj: any) => void, serializationData?: serm.SerializationData): void;
    replace(url: string, apiVersion: string, resources: any, customHeaders: ifm.IHeaders, onResult: (err: any, statusCode: number, obj: any) => void): void;
    _getJson(verb: string, url: string, apiVersion: string, customHeaders: ifm.IHeaders, onResult: (err: any, statusCode: number, obj: any) => void): void;
    _sendJson(verb: string, url: string, apiVersion: string, resources: any, customHeaders: ifm.IHeaders, onResult: (err: any, statusCode: number, obj: any) => void): void;
    createAcceptHeader(type: string, apiVersion?: string): string;
}
