import basem = require('./ClientApiBases');
import VsoBaseInterfaces = require('./interfaces/common/VsoBaseInterfaces');
import TokenInterfaces = require("./interfaces/TokenInterfaces");
import VSSInterfaces = require("./interfaces/common/VSSInterfaces");
export interface ITokenApi extends basem.ClientApiBase {
    authorize(redirectUri: string, responseType: TokenInterfaces.ResponseType, clientId: string, scopes: string, userId?: string): Promise<TokenInterfaces.AuthorizationDecision>;
    getAuthorizations(userId?: string): Promise<TokenInterfaces.AuthorizationDetails[]>;
    initiateAuthorization(redirectUri: string, responseType: TokenInterfaces.ResponseType, clientId: string, scopes: string, userId?: string): Promise<TokenInterfaces.AuthorizationDescription>;
    revokeAuthorization(authorizationId: string, userId?: string): Promise<void>;
    host(clientId: string): Promise<void>;
    revoke(clientId: string, hostId?: string): Promise<void>;
    create(registration: TokenInterfaces.Registration, includeSecret?: boolean): Promise<TokenInterfaces.Registration>;
    delete(registrationId: string): Promise<void>;
    get(registrationId: string, includeSecret: boolean): Promise<TokenInterfaces.Registration>;
    list(): Promise<TokenInterfaces.Registration[]>;
    update(registration: TokenInterfaces.Registration, includeSecret?: boolean): Promise<TokenInterfaces.Registration>;
    getSecret(registrationId: string): Promise<VSSInterfaces.JsonWebToken>;
}
export declare class TokenApi extends basem.ClientApiBase implements ITokenApi {
    constructor(baseUrl: string, handlers: VsoBaseInterfaces.IRequestHandler[]);
    /**
    * @param {string} redirectUri
    * @param {TokenInterfaces.ResponseType} responseType
    * @param {string} clientId
    * @param {string} scopes
    * @param {string} userId
    */
    authorize(redirectUri: string, responseType: TokenInterfaces.ResponseType, clientId: string, scopes: string, userId?: string): Promise<TokenInterfaces.AuthorizationDecision>;
    /**
    * @param {string} userId
    */
    getAuthorizations(userId?: string): Promise<TokenInterfaces.AuthorizationDetails[]>;
    /**
    * @param {string} redirectUri
    * @param {TokenInterfaces.ResponseType} responseType
    * @param {string} clientId
    * @param {string} scopes
    * @param {string} userId
    */
    initiateAuthorization(redirectUri: string, responseType: TokenInterfaces.ResponseType, clientId: string, scopes: string, userId?: string): Promise<TokenInterfaces.AuthorizationDescription>;
    /**
    * @param {string} authorizationId
    * @param {string} userId
    */
    revokeAuthorization(authorizationId: string, userId?: string): Promise<void>;
    /**
    * @param {string} clientId
    */
    host(clientId: string): Promise<void>;
    /**
    * @param {string} clientId
    * @param {string} hostId
    */
    revoke(clientId: string, hostId?: string): Promise<void>;
    /**
    * @param {TokenInterfaces.Registration} registration
    * @param {boolean} includeSecret
    */
    create(registration: TokenInterfaces.Registration, includeSecret?: boolean): Promise<TokenInterfaces.Registration>;
    /**
    * @param {string} registrationId
    */
    delete(registrationId: string): Promise<void>;
    /**
    * @param {string} registrationId
    * @param {boolean} includeSecret
    */
    get(registrationId: string, includeSecret: boolean): Promise<TokenInterfaces.Registration>;
    /**
    */
    list(): Promise<TokenInterfaces.Registration[]>;
    /**
    * @param {TokenInterfaces.Registration} registration
    * @param {boolean} includeSecret
    */
    update(registration: TokenInterfaces.Registration, includeSecret?: boolean): Promise<TokenInterfaces.Registration>;
    /**
    * @param {string} registrationId
    */
    getSecret(registrationId: string): Promise<VSSInterfaces.JsonWebToken>;
}
